<template>
  <div class="loginBox">
    <van-nav-bar>
      <template #left>
        <van-icon @click="pageBack" name="arrow-left" size="18" />
      </template>
      <template #title>
        <label>{{$t('simpleLoginPage.forgetPassword.TR')}}</label>
      </template>
    </van-nav-bar>
    <div class="login_main">
      <van-form colon validate-trigger="onSubmit" :show-error="true">
        <van-field
          required
          v-model="fromData.TelPhoneNumber"
          name="telphone"
          :label="$t('header.telPhoneNumber.TR')"
          :placeholder="$t('simpleLoginPage.formValidate.TelPhone0.TR')"
          :rules="[{validator:isNull,message:$t('simpleLoginPage.formValidate.TelPhone1.TR')}]"
          autocomplete
        />
       <van-field :disabled="isDisableUserType" name="userType" :label="$t('simpleLoginPage.userType.TR')">
          <template #input>
            <van-switch
              :disabled="isDisableUserType"
              v-model="fromData.userType"
              active-value="#3b3b3b"
              size="20"
            ></van-switch>
            <span
              style="margin-left:5px;"
              :style="fromData.userType?'color:#3b3b3b':''"
            >{{fromData.userType?$t('simpleLoginPage.userType0.TR'):$t('simpleLoginPage.userType1.TR')}}</span>
          </template>
        </van-field>
        <div style="margin: 16px;">
          <van-button
            class="loginBtn"
            round
            block
            type="info"
            @click="onSubmit"
            native-type="submit"
          >{{$t('header.define.TR')}}</van-button>
        </div>
      </van-form>
    </div>
  </div>
</template>

<script>
import constParas from "@/utils/constParas";
import languageMixin from "@/mixin/language";
export default {
  mixins: [languageMixin],
  data() {
    return {
      m_Title: "",
      isDisableUserType:false,
      fromData: {
        userType:false,
        TelPhoneNumber:""
      },
    };
  },
  mounted() {
    this.m_Title =  this.getSoftName();;
    document.title  = this.m_Title
    this.isDisableUserType = window.pageConfig.LoginPage.isClickUserType;
    this.fromData.userType = window.pageConfig.LoginPage.isOnlyEmplyeeLogin;
  },
  methods: {
    //提交表单验证成功时触发
    onSubmit(values) {
      let _this = this;
      if (this.fromData.TelPhoneNumber == "") {
        return;
      }
      // console.log("submit", values)
      let Toast = _this.$toast;
      //console.log(this.$refs[formName],237)
      let url = this.$globalConfig.WebApiUrl.MainUrl + "v1/UserInfo/SendPwdToMsg";
      let data = {
        UserType: this.fromData.userType
          ? constParas.UserType.Employee
          : constParas.UserType.OuterUser,
        Telphone:this.fromData.TelPhoneNumber
      };
      // console.log(data,11)
      this.$axios({
        url: url,
        method: "post",
        params: data, //get 用params,post 用 data
        headers: { "Content-Type": "application/json" }
      })
        .then(function(res) {
           console.log(res);
          let resdata = res.data;
          if (resdata.Code != 0) {
            Toast(resdata.Message);
            return;
          }
          Toast.success(`${_this.$t('simpleLoginPage.sendSuccess.TR')}`);
        })
        .catch(msg => {
          // console.log(msg);
          // _this.$notify.error({
          //   title: "登录提示",
          //   duration: 1500,
          //   message: msg,
          // });
        });
    },
    isNull(str) {
      if (str == "") return false;
      return true;
    },
    //返回上一页
    pageBack() {
      this.$router.go(-1);
    }
  }
};
</script>

<style lang="scss">
</style>